==> Combine-3.4.4-1.tar.gz: Combine-3.4/doc/HTML/images.pl <==
# LaTeX2HTML 2002-2-1 (1.70)
# Associate images original text with physical files.


$key = q/includegraphics[height=0.4textheight]{Config.ps};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="621" HEIGHT="445" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img23.png"
 ALT="\includegraphics[height=0.4\textheight]{Config.ps}">|; 

$key = q/geq;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$\geq$">|; 

$key = q/weight[mbox{term}_{i}];MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="107" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$weight[\mbox{term}_{i}]$">|; 

$key = q/includegraphics[height=0.6textheight]{CrawlerArchitecture.xfig.eps};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="327" HEIGHT="687" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="\includegraphics[height=0.6\textheight]{CrawlerArchitecture.xfig.eps}">|; 

$key = q/weight[mbox{location}_{j}];MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="134" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="$weight[\mbox{location}_{j}]$">|; 

$key = q/position[mbox{term}_{i}][mbox{match}_{j}];MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="181" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="$position[\mbox{term}_{i}][\mbox{match}_{j}]$">|; 

$key = q/{displaymath}mbox{Relevance_score}={displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="144" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\begin{displaymath}\mbox{Relevance\_score} = \end{displaymath}">|; 

$key = q/hits[mbox{location}_{j}][mbox{term}_{i}];MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="162" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="$hits[\mbox{location}_{j}][\mbox{term}_{i}]$">|; 

$key = q/mbox{term}_{i};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="45" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="$\mbox{term}_{i}$">|; 

$key = q/{displaymath}sum_{mbox{allterms}}left(sum_{mbox{allmatches}}frac{weight[mbox{terroximity[mbox{term}_{i}][mbox{match}_{j}]}right){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="632" HEIGHT="64" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="\begin{displaymath}\sum_{\mbox{all terms}} \left( \sum_{\mbox{all matches}}
\fra...
..._{j}]) * proximity[\mbox{term}_{i}][\mbox{match}_{j}]} \right) \end{displaymath}">|; 

$key = q/|;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="9" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img24.png"
 ALT="$\vert$">|; 

$key = q/includegraphics[height=0.4textheight]{CrawlerSpeed.ps};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="624" HEIGHT="445" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="\includegraphics[height=0.4\textheight]{CrawlerSpeed.ps}">|; 

$key = q/mbox{location}_{j};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="71" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="$\mbox{location}_{j}$">|; 

$key = q/proximity[mbox{term}_{i}][mbox{match}_{j}];MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="197" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="$proximity[\mbox{term}_{i}][\mbox{match}_{j}]$">|; 

$key = q/>;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="$&gt;$">|; 

$key = q/mbox{match}_{j};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="58" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="$\mbox{match}_{j}$">|; 

$key = q/includegraphics[height=0.3textheightwidth=0.8textwidth]{focusedrobot.eps};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="498" HEIGHT="344" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\includegraphics[height=0.3\textheight width=0.8\textwidth]{focusedrobot.eps}">|; 

$key = q/<;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="$&lt;$">|; 

$key = q/{displaymath}sum_{mbox{alllocations}}left(sum_{mbox{allterms}}(hits[mbox{locatiobox{term}_{i}]*weight[mbox{location}_{j}])right){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="626" HEIGHT="64" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\begin{displaymath}\sum_{\mbox{all locations}} \left( \sum_{\mbox{all terms}} (h...
...weight[\mbox{term}_{i}] * weight[\mbox{location}_{j}]) \right) \end{displaymath}">|; 

$key = q/backslash;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$\backslash$">|; 

$key = q/includegraphics[width=textwidth]{TopicFilter.xfig.eps};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="553" HEIGHT="283" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="\includegraphics[width=\textwidth]{TopicFilter.xfig.eps}">|; 

$key = q/k;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="$k$">|; 

$key = q/0.5;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="27" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="$0.5$">|; 

$key = q/log(distance_between_components);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="286" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="$\log(distance\_between\_components)$">|; 

1;

==> Combine-3.5.tar.gz: Combine-3.5/doc/HTML/images.pl <==
# LaTeX2HTML 2002-2-1 (1.70)
# Associate images original text with physical files.


$key = q/includegraphics[height=0.3textheightwidth=0.6textwidth]{focusedrobot.eps};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="498" HEIGHT="344" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\includegraphics[height=0.3\textheight width=0.6\textwidth]{focusedrobot.eps}">|; 

$key = q/includegraphics[height=0.4textheight]{Config.ps};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="621" HEIGHT="445" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img23.png"
 ALT="\includegraphics[height=0.4\textheight]{Config.ps}">|; 

$key = q/geq;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$\geq$">|; 

$key = q/weight[mbox{term}_{i}];MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="107" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$weight[\mbox{term}_{i}]$">|; 

$key = q/includegraphics[height=0.6textheight]{CrawlerArchitecture.xfig.eps};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="327" HEIGHT="687" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="\includegraphics[height=0.6\textheight]{CrawlerArchitecture.xfig.eps}">|; 

$key = q/weight[mbox{location}_{j}];MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="134" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="$weight[\mbox{location}_{j}]$">|; 

$key = q/includegraphics[width=140mmheight=90mm]{crawl.ps};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="727" HEIGHT="882" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img24.png"
 ALT="\includegraphics[width=140mm height=90mm]{crawl.ps}">|; 

$key = q/position[mbox{term}_{i}][mbox{match}_{j}];MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="181" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="$position[\mbox{term}_{i}][\mbox{match}_{j}]$">|; 

$key = q/{displaymath}mbox{Relevance_score}={displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="144" HEIGHT="31" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\begin{displaymath}\mbox{Relevance\_score} = \end{displaymath}">|; 

$key = q/hits[mbox{location}_{j}][mbox{term}_{i}];MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="162" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="$hits[\mbox{location}_{j}][\mbox{term}_{i}]$">|; 

$key = q/mbox{term}_{i};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="45" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="$\mbox{term}_{i}$">|; 

$key = q/{displaymath}sum_{mbox{allterms}}left(sum_{mbox{allmatches}}frac{weight[mbox{terroximity[mbox{term}_{i}][mbox{match}_{j}]}right){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="632" HEIGHT="64" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="\begin{displaymath}\sum_{\mbox{all terms}} \left( \sum_{\mbox{all matches}}
\fra...
..._{j}]) * proximity[\mbox{term}_{i}][\mbox{match}_{j}]} \right) \end{displaymath}">|; 

$key = q/|;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="9" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img25.png"
 ALT="$\vert$">|; 

$key = q/includegraphics[height=0.4textheight]{CrawlerSpeed.ps};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="624" HEIGHT="445" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="\includegraphics[height=0.4\textheight]{CrawlerSpeed.ps}">|; 

$key = q/mbox{location}_{j};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="71" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="$\mbox{location}_{j}$">|; 

$key = q/proximity[mbox{term}_{i}][mbox{match}_{j}];MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="197" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="$proximity[\mbox{term}_{i}][\mbox{match}_{j}]$">|; 

$key = q/>;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="$&gt;$">|; 

$key = q/mbox{match}_{j};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="58" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="$\mbox{match}_{j}$">|; 

$key = q/<;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="$&lt;$">|; 

$key = q/{displaymath}sum_{mbox{alllocations}}left(sum_{mbox{allterms}}(hits[mbox{locatiobox{term}_{i}]*weight[mbox{location}_{j}])right){displaymath};MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="626" HEIGHT="64" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\begin{displaymath}\sum_{\mbox{all locations}} \left( \sum_{\mbox{all terms}} (h...
...weight[\mbox{term}_{i}] * weight[\mbox{location}_{j}]) \right) \end{displaymath}">|; 

$key = q/backslash;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$\backslash$">|; 

$key = q/includegraphics[width=textwidth]{TopicFilter.xfig.eps};LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="553" HEIGHT="283" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="\includegraphics[width=\textwidth]{TopicFilter.xfig.eps}">|; 

$key = q/k;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="$k$">|; 

$key = q/0.5;MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="27" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="$0.5$">|; 

$key = q/log(distance_between_components);MSF=1.6;LFS=11;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="286" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="$\log(distance\_between\_components)$">|; 

1;
